#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.22
%define baseversionminus1 1.21

Name:           kubernetes%{baseversion}
Version:        1.22.17
Release:        4.2
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
# Patch to revert renaming of coredns image location to match how it's done on download.opensuse.org
Patch5:         revert-coredns-image-renaming.patch
Patch6:         kubernetes-sort-custom-column-print-flags.patch
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go >= 1.16.14
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.16
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.







# packages to build containerized control plane

%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       cri-tools
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes-client-common >= %{version}
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common
Obsoletes:      kubernetes%{baseversionminus1}-client-common

%package client-bash-completion
Summary:        Bash Completion for %{name}-client
Group:          System/Shells
Requires:       bash-completion
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and bash-completion)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-bash-completion
Provides:       kubernetes-client-bash-completion = %{version}
Conflicts:      kubernetes-client-bash-completion

%description client-bash-completion
Bash command line completion support for %{name}-client

%description client-common
Kubernetes client tools common files

%prep
%setup -q -n kubernetes-%{version}
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p0
%patch -P 5 -p1
%patch -P 6 -p1

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
%ifarch ppc64le
export GOLDFLAGS='-linkmode=external'
%endif

#TEST
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} %(echo %{baseversion} | tr -d .)

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
%service_add_post kubelet.service
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*

%files client-bash-completion
%{_datadir}/bash-completion/completions/kubectl

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Jan 10 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add kubernetes-sort-custom-column-print-flags.patch
  for reproducible builds
* Mon Mar 27 2023 Robert Munteanu <rombert@apache.org>
- Stronger conflicts for completion packages
* Mon Mar 27 2023 Robert Munteanu <rombert@apache.org>
- Split individual completions into separate packages
* Wed Mar  1 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- update patch files to reflect upstream registry changes from k8s.gcr.io to registry.k8s.io
  * kubeadm-opensuse-registry.patch
  * revert-coredns-image-renaming.patch
* Thu Feb 23 2023 priyanka.saggu@suse.com
- Update to version 1.22.17:
  * Release commit for Kubernetes v1.22.17
  * backport change all k8s.gcr.io to registry.k8s.io on release-1.22
  * Fix endpoint reconciler failing to delete masterlease
  * use etcd 3.5.6-0 after promotion
  * changelog: CVE-2022-3294 and CVE-2022-3162 were fixed in v1.23.14
  * hack/scripts: use registry.k8s.io
  * kubeadm: mutate ClusterConfiguration.imageRepository to "registry.k8s.io"
  * kubeadm: use registry.k8s.io instead of k8s.gcr.io
  * kubeadm: allow RSA and ECDSA format keys in preflight check
  * Limit redirect proxy handling to redirected responses
  * Reduce default gzip compression level from 4 to 1 in apiserver
  * client-go: make retry in Request thread safe
  * exec auth: support TLS config caching
  * client-go exec: make sure round tripper can be unwrapped
  * Automated cherry pick of #111009: Windows: ensure runAsNonRoot does case-insensitive comparison (#112213)
  * Fix problem in updating VolumeAttached in node status
  * Add etcd initialization in openapi tests
  * Tolerate sub-microsecond eventTime changes on update
  * fix a memory leak problem when calling DryRunPreemption
  * Fix kubelet panic when accessing metrics/resource endpoint
  * Fixing logic for kubelet permissions check on windows
  * kubeadm: fix the bug that configurable KubernetesVersion not respected during kubeadm join
  * Bump cAdvisor to v0.39.4
  * Fix: filter out unsatisfied nodes when calling AddPod in PodTopologySpread
  * kubeadm: fix the bug that configurable KubernetesVersion not respected during kubeadm join
  * GIT-110239: fix activeDeadlineSeconds enforcement bug
  * fix: --chunk-size with selector returns missing result
  * Fixed winkernel proxy failing to query v1 endpoints created by dockershim CNIs
  * Winkernel proxier cache HNS data to improve syncProxyRules performance
  * apiserver: printers should use int64
  * Revert "Automated cherry pick of #109124: Winkernel proxier cache HNS data to improve syncProxyRules"
  * Prune defaults for CRD serving
  * fix image pulling failure when IMDS is unavailalbe in kubelet startup
  * test: update graceful node shutdown e2e with watch
  * Ignore EndpointSlices that are already marked for deletion
  * kubelet: Mark ready condition as false explicitly for terminal pods
  * agnhost: bump version 2.39
  * kubelet: add e2e test to verify probe readiness
  * kubelet: only shutdown probes for pods that are terminated
  * kubelet: Pod probes should be handled by pod worker
  * Reject proxy requests to 0.0.0.0 as well
  * etcd-client starts retrying transient errors from the etcd cluster
  * ipvs: fix prevent concurrent map read and map write
  * restore endpoints topology fallback in kube-proxy, fix issue 110208
  * fix audit union loop variables in closures
  * Updating e2e test to check EndpointSlices and Endpoints as well
  * e2e: services with evicted pods doesn't have endpoints
  * e2e test for evicted pods
  * endpoints controller: don't consider terminal endpoints
  * endpointslices: terminal pods doesn't receive enpoints
  * add pod util to verify pod is terminal
  * untangled HNS caching fix with healthCheck feature
  * Fix requests scope classification
  * authn: fix cache mutation by AuthenticatedGroupAdder
  * Winkernel proxier cache HNS data to improve syncProxyRules performance
  * fix: exclude non-ready nodes and deleted nodes from azure load balancers
  * Fix OpenAPI loading error caused by empty APIService
  * tests: Updates the should delete a collection of pods test
  * component-base: replace url in rest client metrics
  * Fix name for Pods of NonIndexed Jobs
  * Correct event registration for multiple scheduler plugins.
  * Avoid updating Services with stale specs Fix the bug that service specs in servicesToUpdate may have been updated by clients.
  * Fix: abort nominating a pod that was already scheduled to a node
  * cpu manager policy set to none, no one remove container id from container map, lead memory leak
  * kubeadm: add etcd flag for member data consistency
  * Copy request in timeout handler
  * kube-up: use registry.k8s.io for containerd-related jobs
  * Skip updating Endpoints and EndpointSlice if no relevant fields change
  * ipvs: remove port opener
  * iptables: remove port opener
  * kubelet: If the container status is created, we are waiting
  * rootcacertpublisher: drop the namespace label from metrics to reduce its cardinality
  * Include pod UID in secret/configmap cache key
  * Move kubelet secret and configmap manager calls to sync_Pod functions
  * Extract containerID from systemd-style cgroupPath in cri_stats_provider And fix test to generate UUID without dash
  * test: Add E2E for job completions with cpu reservation
  * test: Add E2E for init container pod deletion
  * kubelet: Delay writing a terminal phase until the pod is terminated
  * azure_file: try to get secret namespace from ClaimRef
  * azure_file: add namespace tests for InTree to CSI conversion
  * Update Go to 1.16.15
  * cluster/gce: update konnectivity image tags to v0.0.30
  * wrap error from RunCordonOrUncordon
  * bump sigs.k8s.io/apiserver-network-proxy/konnectivity-client@v0.0.30
  * fix dryrun when ca file exists
  * fix regression introduced by PR 100320
  * Fix nodes volumesAttached status not updated
  * remove InitFlags for pod_workers test
  * cronjob_controllerv2: do not filter jobs to be reconciled by labels
  * kubelet: Clean up a static pod that has been terminated before starting
  * Add an e2e test for updating a static pod while it restarts
  * kubelet: fix podstatus not containing pod full name
  * increase Azure ACR credential provider timeout
  * Updating EndpointSlice strategy to retain node name in topology until field is set
  * Ignore container notfound error while getPodstatuses
  * fix: do not return early in the node informer when there is no change of the topology label.
  * Add PDB selector patch integration test
  * Revert v1beta1 PodDisruptionBudget select patchStrategy
  * kubeadm: fix the bug that 'kubeadm init --dry-run --upload-certs' command failed with 'secret not found' error
  * tests: Wait for pod collection to enter a Running state
* Wed Mar 16 2022 rbrown@suse.com
- Update to version 1.22.7:
  * Update Go to 1.16.14
  * add namespace in azurefile volumeid
  * fix: azurefile volumeid conflict in csi migration
  * Execute sync before taking the snapshot
  * Mark device as uncertain if unmount device succeeds
  * Set max results if its not set
  * Update CHANGELOG/CHANGELOG-1.22.md for v1.22.6
  * Update k/utils to v0.0.0-20211116205334-6203023598ed
  * [go] update to Go 1.16.13
  * Enabling kube-proxy metrics on windows kernel mode
  * fix: ignore the case when comparing azure tags in service annotation
  * fix: remove outdated ipv4 route when the corresponding node is deleted
  * fix: delete non existing disk issue
  * fix containers order after applying
  * generated: ./hack/update-vendor.sh
  * upgrade sigs.k8s.io/structured-merge-diff/v4 to v4.2.1
  * fix: azuredisk parameter lowercase translation issue
  * fix: do not delete the lb that does not exist
  * removed unnecessary log line
  * Fix header mutation race in timeout filter
  * use node informer to check volumes attachment status before backoff
  * When volume is not marked in-use, do not backoff
  * kubeadm: remove the restriction that the ca.crt can only contain one certificate
  * flake fix: remove the error handler for cronjob integration test
  * vendor: bump cAdvisor to v0.39.3
  * Fix the leak of vSphere client sessions
  * fix nil pointer in create secret commands
  * client-go: Clear the ResourceVersionMatch on paged list calls
  * Update GCE manifest to use konnectivity 0.0.27
  * Update to apiserver-network-proxy v0.0.27
  * add gce loadbalancer no-op finalizer and existingFwdRule tests
  * disable gce service handling if has rbs forwarding rule
  * add ELBRbsFinalizer
  * add gce elb rbs opt-in annotation
  * Improving performance of EndpointSlice controller metrics cache
  * fix the error when cleaning up jobs for cronjob
  * Update CHANGELOG/CHANGELOG-1.22.md for v1.22.5
  * Add test to confirm containers won't start
  * Check for failed sandbox and failed workload containers
  * mount-utils: Detect potential stale file handle
  * [go1.16] Update to go1.16.12
  * Skip creating HNS loadbalancer with empty endpoints
  * dependencies: Update golang.org/x/net to v0.0.0-20211209124913-491a49abca63
  * kubeadm: avoid requiring a CA key during kubeconfig expiration checks
  * kubeadm: print the CA of kubeconfig files in "check expiration"
  * kubeadm: validate local etcd certficates during expiration checks
  * kubelet: set failed phase during graceful shutdown
  * [go1.16] Update to go1.16.11
  * fix: ignore the case when updating tags
  * Ensure deletion of pods in queues and cache
  * kubelet: Rejected pods should be filtered from admission
  * kube-scheduler: Increase the duration to expire an assumed pod
  * Skip check for all topology labels when using system default spreading
  * workqueue: fix leak in queue preventing objects from being GCed
  * Fix workqueue memory leak
  * Ignore 'wait: no child processes' error when calling mount/umount
  * Reduce calls to docker from dockershim for stats
  * Update CHANGELOG/CHANGELOG-1.22.md for v1.22.4
  * Add warning about using unsupported CRON_TZ
  * Fix flake caused by sampling signal counter too early.
  * Ensure there is one running static pod with the same full name
  * NodeConformance: Respect grace period when updating static pod
  * Fix concurrent map writes error in kube-apiserver
  * e2e: node: release-1.22: backport findKubeletServiceName
  * node: e2e: add test for the checkpoint recovery
  * devicemanager: checkpoint: support pre-1.20 data
  * fix: remove VMSS and VMSS instances from SLB backend pool only when necessary
  * fix: leave the probe path empty for TCP probes
  * fix: skip instance not found when decoupling vmss from lb
* Mon Feb  7 2022 Dirk Müller <dmueller@suse.com>
- avoid bashism in client-common postinstall script (bsc#1195391)
* Fri Dec 17 2021 Richard Brown <rbrown@suse.com>
- Tidy up merge marker
* Wed Dec  8 2021 rbrown@suse.com
- Update to version 1.22.4:
  * defer close the rotated log open
  * proxy/iptables: fix all-vs-ready endpoints a bit
  * proxy/iptables: Remove a no-op check
  * proxy/iptables: Add more stuff to the unit test
  * proxy/iptables: Fix TestOnlyLocalNodePortsNoClusterCIDR
  * proxy/iptables: test that we create a consistent set of iptables rules
  * proxy/iptables: Misc improvements to unit test
  * proxy/iptables: Improve the sorting logic in TestOverallIPTablesRulesWithMultipleServices
  * proxy/iptables: Fix sync_proxy_rules_iptables_total metric
  * Fixed nil pointer dereference
  * Add tests for checking bind mounts
  * Check subpath file
  * Add check for subpaths
  * Fixed unit test SELinux support
  * Add shortcut for SELinux detection
  * Don't guess SELinux support on error
  * Manual cherry pick of kube-openapi changes for release-1.22 Bump kube-openapi against kube-openapi/release-1.22 branch
  * kube-proxy: fix stale detection logic
  * Use separate pathSpec for local and remote to properly handle cleaning paths
  * [go1.16] Update to go1.16.10
  * Automated cherry pick of #105122: added keys for structured logging (#105137)
  * Update debian, debian-iptables, setcap images to pick up CVE-2021-33910 fixes
  * Fixing how EndpointSlice Mirroring handles Service selector transitions
  * Add unit tests to cover scheduler's setup
  * sched: ensure feature gate is honored when instantiating scheduler
  * Fix race condition in logging when request times out
  * use original requests in NodeResourcesBalancedAllocation instead of NonZero
  * Remove nodes with Cluster Autoscaler taint from LB backends.
  * Fix issue in node status updating VolumeAttached list
  * Support cgroupv2 in node problem detector test
  * Update CHANGELOG/CHANGELOG-1.22.md for v1.22.3
  * Free APF seats for watches handled by an aggregated apiserver.
  * parameter 'disabled-metrics' is invalid
  * Run storage hostpath e2e test client pod as privileged
  * support more than 100 disk mounts on Windows
  * [go1.16] Update to go1.16.9
  * Clear initial UDP conntrack entries for loadBalancerIPs
  * Verifying the auth headers are set for upgraded aggregated API requests
  * apiserver aggregator upgrade unit test
  * Aggregator uses the regular transport even if the request requires upgrades
  * Fix PreferNominatedNode test
  * Remove Error Message Check Dynamic PV Tests
  * go fmt
  * Add e2e test to verify kubelet restart behaviour
  * kubelet: set terminated podWorker status for terminated pods
  * Fix quota controller hotloop in integration tests
  * remove StartedPodsErrorsTotal metrice message
  * Copy VolumeSnapshotContent annotations in snapshottable.go test
  * Fix bugs in e2e pod test
  * Ensure terminal pods maintain terminal status
  * Do not sync Waiting statuses for Terminated pods
  * Adds CancelRequest function to CommandHeadersRoundTripper
  * Fixes kubectl command headers which hangs on kubectl run
  * Revert "Build non-static binaries with PIE buildmode"
  * Ignore VMs in vmss delete backend pools
  * Fix CSR test to accept certs shorter than the requested duration
  * fix: skip not found nodes when reconciling LB backend address pools
  * fix: consolidate logs for instance not found error
  * Remove a duplicate StorageClass creation call
  * Update Containerd version - GCE Windows
  * e2e scheduling priorities: do not reference control loop variable
  * storege e2etest: Delete restored PVC/Pod in snapshottable
  * pkg/kubelet/cm/memorymanager: Fix ErrorS key/value pair
  * v1.22: Fix test flake in old svc registry
  * 'New' Event namespace validate failed
  * kubelet: Handle UID reuse in pod worker
  * Add test for recreating a static pod
  * Update CHANGELOG/CHANGELOG-1.22.md for v1.22.2
  * Refine locking in API Priority and Fairness config controller
  * kube-controller-manager: properly check generic ephemeral volume feature
  * Fix null JSON round tripping
  * Propagate conversion errors
  * integration test
  * fix 104329: check for headless before trying to release the ClusterIPs
  * fix detach disk issue on deleting node
  * kubelet: fix sandbox creation error suppression when pods are quickly deleted
  * remove listx from OWNERS_ALIASES
* Thu Sep 16 2021 rbrown@suse.com
- Update to version 1.22.2:
  * [go1.16] Update to go1.16.8
  * Fix Job tracking with finalizers for more than 500 pods
  * e2e iperf2 change threshold to 10MBps = 80 Mbps
  * legacy-cloud-providers: aws: Add support for consuming web identity credentials
  * Fix the key missing issue for structured log
  * add a test for jsonpath template parsing to prevent regressions
  * revert "fix wrong output when using jsonpath"
  * Fix a small regression in Service updates
  * kubelet: Admission must exclude completed pods and avoid races
  * Don't prematurely close reflectors in case of slow initialization in watch based manager
  * backport 104410 to release-1.22
  * Fix storage class setup in regional_pd.go
  * pkg/kubelet/cm: use SkipFreezeOnSet
  * vendor: bump runc to 1.0.2
  * vendor: bump k8s.io/util to get fix for LRU cache
  * Update CHANGELOG/CHANGELOG-1.22.md for v1.22.1
  * fix: ensure InstanceShutdownByProviderID return false for creating Azure VMs
  * fix: skip case sensitivity when checking Azure NSG rules
  * Copy golang license to staging copies
* Wed Sep  1 2021 Richard Brown <rbrown@suse.com>
- Tiding up old sources (remove kubernetes-1.22.0.obscpio)
* Wed Aug 25 2021 rbrown@suse.com
- Update to version 1.22.1:
  * Keep MakeMountArgSensitive and add a new signature that receives flags
  * Update the unit tests to handle mountFlags
  * Add missing interface method in mount_unsupported.go
  * Pass additional flags to subpath mount to avoid flakes in certain conditions
  * device manager: do not clean admitted pods from the state
  * memory manager: do not clean admitted pods from the state
  * cpu manager: do not clean admitted pods from the state
  * Avoid spurious calls to update/delete validation
  * Update to go1.16.7
  * Pass unknown labels in allowedTopologies during CSI translation
  * Fix metrics reporting for the deprecated watch path
  * Update configure-helper.sh
  * Update configure-helper.sh
  * Update configure-helper.sh
  * Remove duplicate dependencies from 1.22 changelog
  * replace e2e WaitForPodsReady by WaitTimeoutForPodReadyInNamespace
  * delete stale UDP conntrack entries for loadbalancer IPs
  * Update CHANGELOG/CHANGELOG-1.22.md for v1.22.0
  * Set idle and readheader timeouts
* Fri Aug  6 2021 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial Package
